/****************************************************************
 * Licensed to the Apache Software Foundation (ASF) under one   *
 * or more contributor license agreements.  See the NOTICE file *
 * distributed with this work for additional information        *
 * regarding copyright ownership.  The ASF licenses this file   *
 * to you under the Apache License, Version 2.0 (the            *
 * "License"); you may not use this file except in compliance   *
 * with the License.  You may obtain a copy of the License at   *
 *                                                              *
 *   http://www.apache.org/licenses/LICENSE-2.0                 *
 *                                                              *
 * Unless required by applicable law or agreed to in writing,   *
 * software distributed under the License is distributed on an  *
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY       *
 * KIND, either express or implied.  See the License for the    *
 * specific language governing permissions and limitations      *
 * under the License.                                           *
 ****************************************************************/

package org.apache.james.mailbox.cassandra.modules;

import static com.datastax.driver.core.DataType.text;

import java.util.List;

import org.apache.james.backends.cassandra.components.CassandraModule;
import org.apache.james.backends.cassandra.components.CassandraTable;
import org.apache.james.backends.cassandra.components.CassandraType;
import org.apache.james.mailbox.cassandra.table.CassandraSubscriptionTable;

import com.datastax.driver.core.schemabuilder.SchemaBuilder;
import com.google.common.collect.ImmutableList;

public class CassandraSubscriptionModule implements CassandraModule {

    public static final int PER_USER_CACHED_SUBSCRIPTIONS = 100;
    private final List<CassandraTable> tables;
    private final List<CassandraType> types;

    public CassandraSubscriptionModule() {
        tables = ImmutableList.of(
            new CassandraTable(CassandraSubscriptionTable.TABLE_NAME,
                SchemaBuilder.createTable(CassandraSubscriptionTable.TABLE_NAME)
                    .ifNotExists()
                    .addPartitionKey(CassandraSubscriptionTable.USER, text())
                    .addClusteringColumn(CassandraSubscriptionTable.MAILBOX, text())
                    .withOptions()
                    .comment("Holds per user list of IMAP subscriptions")
                    .caching(SchemaBuilder.KeyCaching.ALL,
                        SchemaBuilder.rows(PER_USER_CACHED_SUBSCRIPTIONS))));
        types = ImmutableList.of();
    }

    @Override
    public List<CassandraTable> moduleTables() {
        return tables;
    }

    @Override
    public List<CassandraType> moduleTypes() {
        return types;
    }
}
